==> form-wallet-web-1.1.59.tgz: package/src/views/wallet/components/server.js <==
import Vue from 'vue'
export default class Server {
  constructor(params) {

  }
  // 查询票夹信息
  getWalletList(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/findHinvoiceInfoPageListByMobile`, param).then((response) => {
        const res = {
          list: [],
          pageNum: 0,
          total: 0
        }
        const resData = {
          data: response.data.obj ? response.data.obj : res
        }
        resolve(resData);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 删除发票
  deleteWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/deleteInvoiceInfoByPrimaryKeyUUid`, param).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 批量删除发票  todo
  batchDeleteWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/invoice/batchDeleteInvoiceInfoByPrimaryKeyUuid`, param).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //查询票据详情
  queryWalletDetail(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/selectByPrimaryKeyUUid`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //查询发票类型
  queryWalletType(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/selectHtypeItemsByExample`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //获取字段映射信息
  getMapInfo(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/selectElementConfigListByExample`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //查询票据信息模板
  queryWalletTemplate(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/selectInvoiceElementListSelective`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //查询税率
  queryTaxrate(param) {
    return new Promise((resolve) => {
      $axios.post(`/ems-base-application/tax/findTaxRateValueByOuList/${param}`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //获取已报账单号相关参数
  getSubmitAccount(param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsUtServiceURL}/claimProcessTaskMgr/findmyapp`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //保存票夹信息之前-弱校验提示接口  todo
  checkWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/pc/invoice/historicalInvoiceNoCheck`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //保存票夹信息
  saveWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/saveInvoiceInfoSelective`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 查询转交人列表 updateInvoiceOwnedBy
  queryPassedPeople(param) {
    return new Promise((resolve) => {
      $axios.post(`/ems/ems-base-application/sysorg/findSubEmployees/allOrg/2`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 转交人接口
  deliverPeople(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/updateInvoiceOwnedBy`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 编辑票夹
  editTicket(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/updateInvoiceListInfoByPrimaryKeyUUid`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 查询票夹初始化
  queryWalletList(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/findHinvoiceInfoPageListByMobile`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //通过uuid查询票据详情
  queryWalletByUuids(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/selectByPrimaryKeyUUids`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //编辑保存发票  批量
  saveEditWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/updateInvoiceListInfoByPrimaryKeyUUid`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  } 
  //编辑保存发票-针对已关联 todo
  saveEditCloseWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/mobile/invoice/updateInvoiceCloseByUUid`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  searchValueset = params => {
    return new Promise((resolve) => {
      $axios.get(`/ems-base-application/mams/sys/valueset/item/list/INVOICE_MOBILE_TYPE`).then((response) => {
        const data = response.data;
        resolve(data);
      });
    });
  };

  // 查询菜单
  queryMeny = params => {
    return new Promise((resolve) => {
      $axios.post(`/ems/ems-base-application/mams/sys/nav/infoV2`, params).then((response) => {
        const data = response.data;
        resolve(data);
      });
    });
  };

  // 根据tocken 查询用户信息
  findCurrentEmployee = params => {
    return new Promise((resolve) => {
      $axios.get(`/ems/ems-base-application/tsUserOrg/findCurrentEmployee`).then((response) => {
        const data = response.data;
        resolve(data);
      });
    });
  };


 // 查询常用菜单
 calculationShortcutEntrance = params => {
  return new Promise((resolve) => {
    $axios.post(`/bill-service/claim/calculationShortcutEntrance`, params).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};
// 新增常用菜单
inserthome = params => {
  return new Promise((resolve) => {
    $axios.post(`/ems/ems-base-application/mams/sys/menuhome/inserthome`, params).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};

// 值集初始化
searchSeatList = param => {
  return new Promise((resolve) => {
    $axios.get(`/ems-base-application/mams/sys/valueset/item/list/${param}`, param).then((response) => {
      const data = response.data;
      resolve(data);
    });
  })
};
// 税率初始化  todo
findWalletTaxRate = param => {
  return new Promise((resolve) => {
    $axios.get(`/mobileValue/getTaxRate/${param}`, param).then((response) => {
      // const data = response.data;
      const data = response.data;
      resolve(data);
    });
  })
};


}

==> form-wallet-web-1.1.63.tgz: package/src/views/wallet/components/server.js <==
import Vue from 'vue'
export default class Server {
  constructor(params) {

  }
  // 删除发票
  deleteWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/invoice/deleteInvoiceInfoByPrimaryKeyUUid`, param).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 批量删除发票  todo
  batchDeleteWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/invoice/batchDeleteInvoiceInfoByPrimaryKeyUuid`, param).then((response) => {
        resolve(response.data);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }

  //查询发票类型
  queryWalletType(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/htypeItems/selectHtypeItemsByExample`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //获取字段映射信息
  getMapInfo(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/invoiceConfig/selectListByExample`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //查询票据信息模板
  queryWalletTemplate(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/invoiceConfig/selectInvoiceElementListSelective`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //查询税率
  queryTaxrate(param) {
    return new Promise((resolve) => {
      $axios.post(`/ems-base-application/tax/findTaxRateValueByOuList/${param}`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //获取已报账单号相关参数
  getSubmitAccount(param) {
    return new Promise((resolve) => {
      $axios.post(`${process.env.API.emsUtServiceURL}/claimProcessTaskMgr/findmyapp`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //保存票夹信息之前-弱校验提示接口  todo
  checkWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/pc/invoice/historicalInvoiceNoCheck`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //保存票夹信息
  saveWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/saveInvoiceInfoSelective`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 查询转交人列表 updateInvoiceOwnedBy
  queryPassedPeople(param) {
    return new Promise((resolve) => {
      $axios.post(`/ems/ems-base-application/sysorg/findSubEmployees/allOrg/2`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 转交人接口
  deliverPeople(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/updateInvoiceOwnedBy`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 编辑票夹
  editTicket(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/updateInvoiceListInfoByPrimaryKeyUUid`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  // 查询票夹初始化
  queryWalletList(param) {
    return new Promise((resolve) => {
      $axios.post(`/claim-wallet-application/mobile/invoice/findHinvoiceInfoPageListByMobile`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //通过uuid查询票据详情-批量查询暂不修改
  queryWalletByUuids(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/selectByPrimaryKeyUUids`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  //编辑保存发票  批量
  saveEditWallet(param) {
    return new Promise((resolve) => {
      $axios.post(`/mobile-service/appHinvoiceInfoPC/updateInvoiceListInfoByPrimaryKeyUUid`, param).then((response) => {
        resolve(response);
      })
        .catch((error) => {
          let responseData = { "dataResult": [], "extra": "", "msg": "服务异常，请联系管理员", "statusCode": "-1" };
          resolve(responseData);
        })
    })
  }
  searchValueset = params => {
    return new Promise((resolve) => {
      $axios.get(`/ems-base-application/mams/sys/valueset/item/list/INVOICE_MOBILE_TYPE`).then((response) => {
        const data = response.data;
        resolve(data);
      });
    });
  };

  // 查询菜单
  queryMeny = params => {
    return new Promise((resolve) => {
      $axios.post(`/ems/ems-base-application/mams/sys/nav/infoV2`, params).then((response) => {
        const data = response.data;
        resolve(data);
      });
    });
  };

  // 根据tocken 查询用户信息
  findCurrentEmployee = params => {
    return new Promise((resolve) => {
      $axios.get(`/ems/ems-base-application/tsUserOrg/findCurrentEmployee`).then((response) => {
        const data = response.data;
        resolve(data);
      });
    });
  };


 // 查询常用菜单
 calculationShortcutEntrance = params => {
  return new Promise((resolve) => {
    $axios.post(`/bill-service/claim/calculationShortcutEntrance`, params).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};
// 新增常用菜单
inserthome = params => {
  return new Promise((resolve) => {
    $axios.post(`/ems/ems-base-application/mams/sys/menuhome/inserthome`, params).then((response) => {
      const data = response.data;
      resolve(data);
    });
  });
};

// 值集初始化
searchSeatList = param => {
  return new Promise((resolve) => {
    $axios.get(`/ems-base-application/mams/sys/valueset/item/list/${param}`, param).then((response) => {
      const data = response.data;
      resolve(data);
    });
  })
};
// 税率初始化  todo
findWalletTaxRate = param => {
  return new Promise((resolve) => {
    $axios.get(`/mobileValue/getTaxRate/${param}`, param).then((response) => {
      // const data = response.data;
      const data = response.data;
      resolve(data);
    });
  })
};


}
